@@ -1,6 +1,6 @@
 package Net::Stomp::MooseHelpers::TraceOnly;
 {
-  $Net::Stomp::MooseHelpers::TraceOnly::VERSION = '1.3';
+  $Net::Stomp::MooseHelpers::TraceOnly::VERSION = '1.4';
 }
 {
   $Net::Stomp::MooseHelpers::TraceOnly::DIST = 'Net-Stomp-MooseHelpers';
@@ -31,7 +31,7 @@ around '_build_connection' => sub {
 
 package Net::Stomp::MooseHelpers::TraceOnly::Connection;
 {
-  $Net::Stomp::MooseHelpers::TraceOnly::Connection::VERSION = '1.3';
+  $Net::Stomp::MooseHelpers::TraceOnly::Connection::VERSION = '1.4';
 }
 {
   $Net::Stomp::MooseHelpers::TraceOnly::Connection::DIST = 'Net-Stomp-MooseHelpers';
@@ -41,7 +41,15 @@ use Carp;
 
 has _tracing_object => ( is => 'rw' );
 
-sub connect { return 1 }
+sub connect {
+    return Net::Stomp::Frame->new({
+        command => 'CONNECTED',
+        headers => {
+            session => 'ID:foo',
+        },
+        body => '',
+    });
+}
 sub subscribe { return 1 }
 sub unsubscribe { return 1 }
 sub ack { return 1 }
@@ -75,8 +83,9 @@ sub send {
 __PACKAGE__->meta->make_immutable;
 }
 
-__END__
 
+
+__END__
 =pod
 
 =encoding utf-8
@@ -87,7 +96,7 @@ Net::Stomp::MooseHelpers::TraceOnly - role to replace the Net::Stomp connection
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 SYNOPSIS
 
@@ -148,3 +157,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
